obj/main/SITL/io/beeper.o: src/main/io/beeper.c src/main/platform.h \
 src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h \
 src/main/config/feature.h src/main/pg/pg.h src/main/build/build_config.h \
 src/main/drivers/dshot_command.h src/main/drivers/io.h \
 src/main/drivers/resource.h src/main/drivers/io_types.h \
 src/main/drivers/io_def.h src/platform/SIMULATOR/io_def_generated.h \
 src/main/drivers/pwm_output.h src/main/common/time.h \
 src/main/drivers/dma.h src/platform/SIMULATOR/include/platform/dma.h \
 src/main/drivers/motor_types.h src/main/drivers/timer.h \
 src/platform/SIMULATOR/timer_def.h src/main/pg/timerio.h \
 src/main/pg/pg_ids.h src/main/drivers/dma_reqmap.h src/main/pg/motor.h \
 src/main/drivers/sound_beeper.h src/main/drivers/system.h \
 src/main/drivers/time.h src/main/flight/mixer.h src/main/drivers/motor.h \
 src/main/config/config.h src/main/fc/core.h src/main/fc/runtime_config.h \
 src/main/io/statusindicator.h src/main/io/vtx_control.h \
 src/main/fc/rc_modes.h src/main/pg/beeper.h \
 src/main/scheduler/scheduler.h src/main/pg/scheduler.h \
 src/main/sensors/battery.h src/main/common/filter.h \
 src/main/sensors/current.h src/main/sensors/current_ids.h \
 src/main/sensors/voltage.h src/main/sensors/voltage_ids.h \
 src/main/sensors/sensors.h src/main/io/beeper.h
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
src/main/config/feature.h:
src/main/pg/pg.h:
src/main/build/build_config.h:
src/main/drivers/dshot_command.h:
src/main/drivers/io.h:
src/main/drivers/resource.h:
src/main/drivers/io_types.h:
src/main/drivers/io_def.h:
src/platform/SIMULATOR/io_def_generated.h:
src/main/drivers/pwm_output.h:
src/main/common/time.h:
src/main/drivers/dma.h:
src/platform/SIMULATOR/include/platform/dma.h:
src/main/drivers/motor_types.h:
src/main/drivers/timer.h:
src/platform/SIMULATOR/timer_def.h:
src/main/pg/timerio.h:
src/main/pg/pg_ids.h:
src/main/drivers/dma_reqmap.h:
src/main/pg/motor.h:
src/main/drivers/sound_beeper.h:
src/main/drivers/system.h:
src/main/drivers/time.h:
src/main/flight/mixer.h:
src/main/drivers/motor.h:
src/main/config/config.h:
src/main/fc/core.h:
src/main/fc/runtime_config.h:
src/main/io/statusindicator.h:
src/main/io/vtx_control.h:
src/main/fc/rc_modes.h:
src/main/pg/beeper.h:
src/main/scheduler/scheduler.h:
src/main/pg/scheduler.h:
src/main/sensors/battery.h:
src/main/common/filter.h:
src/main/sensors/current.h:
src/main/sensors/current_ids.h:
src/main/sensors/voltage.h:
src/main/sensors/voltage_ids.h:
src/main/sensors/sensors.h:
src/main/io/beeper.h:
